# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/type/matcher/metadata.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/type/matcher/metadata.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.type.matcher import value_pb2 as envoy_dot_type_dot_matcher_dot_value__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!envoy/type/matcher/metadata.proto\x12\x12\x65nvoy.type.matcher\x1a\x1e\x65nvoy/type/matcher/value.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xe5\x01\n\x0fMetadataMatcher\x12\x17\n\x06\x66ilter\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12G\n\x04path\x18\x02 \x03(\x0b\x32/.envoy.type.matcher.MetadataMatcher.PathSegmentB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x12\x39\n\x05value\x18\x03 \x01(\x0b\x32 .envoy.type.matcher.ValueMatcherB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x1a\x35\n\x0bPathSegment\x12\x16\n\x03key\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00\x42\x0e\n\x07segment\x12\x03\xf8\x42\x01\x42v\n io.envoyproxy.envoy.type.matcherB\rMetadataProtoP\x01Z9github.com/envoyproxy/go-control-plane/envoy/type/matcher\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.type.matcher.metadata_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n io.envoyproxy.envoy.type.matcherB\rMetadataProtoP\001Z9github.com/envoyproxy/go-control-plane/envoy/type/matcher\272\200\310\321\006\002\020\001'
  _globals['_METADATAMATCHER_PATHSEGMENT'].oneofs_by_name['segment']._loaded_options = None
  _globals['_METADATAMATCHER_PATHSEGMENT'].oneofs_by_name['segment']._serialized_options = b'\370B\001'
  _globals['_METADATAMATCHER_PATHSEGMENT'].fields_by_name['key']._loaded_options = None
  _globals['_METADATAMATCHER_PATHSEGMENT'].fields_by_name['key']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_METADATAMATCHER'].fields_by_name['filter']._loaded_options = None
  _globals['_METADATAMATCHER'].fields_by_name['filter']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_METADATAMATCHER'].fields_by_name['path']._loaded_options = None
  _globals['_METADATAMATCHER'].fields_by_name['path']._serialized_options = b'\372B\005\222\001\002\010\001'
  _globals['_METADATAMATCHER'].fields_by_name['value']._loaded_options = None
  _globals['_METADATAMATCHER'].fields_by_name['value']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_METADATAMATCHER']._serialized_start=146
  _globals['_METADATAMATCHER']._serialized_end=375
  _globals['_METADATAMATCHER_PATHSEGMENT']._serialized_start=322
  _globals['_METADATAMATCHER_PATHSEGMENT']._serialized_end=375
# @@protoc_insertion_point(module_scope)
