# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/config/common/key_value/v3/config.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/config/common/key_value/v3/config.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import extension_pb2 as envoy_dot_config_dot_core_dot_v3_dot_extension__pb2
from xds.annotations.v3 import status_pb2 as xds_dot_annotations_dot_v3_dot_status__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-envoy/config/common/key_value/v3/config.proto\x12 envoy.config.common.key_value.v3\x1a$envoy/config/core/v3/extension.proto\x1a\x1fxds/annotations/v3/status.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"e\n\x13KeyValueStoreConfig\x12\x44\n\x06\x63onfig\x18\x01 \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01:\x08\xd2\xc6\xa4\xe1\x06\x02\x08\x01\x42\x9c\x01\n.io.envoyproxy.envoy.config.common.key_value.v3B\x0b\x43onfigProtoP\x01ZSgithub.com/envoyproxy/go-control-plane/envoy/config/common/key_value/v3;key_valuev3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.common.key_value.v3.config_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n.io.envoyproxy.envoy.config.common.key_value.v3B\013ConfigProtoP\001ZSgithub.com/envoyproxy/go-control-plane/envoy/config/common/key_value/v3;key_valuev3\272\200\310\321\006\002\020\002'
  _globals['_KEYVALUESTORECONFIG'].fields_by_name['config']._loaded_options = None
  _globals['_KEYVALUESTORECONFIG'].fields_by_name['config']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_KEYVALUESTORECONFIG']._loaded_options = None
  _globals['_KEYVALUESTORECONFIG']._serialized_options = b'\322\306\244\341\006\002\010\001'
  _globals['_KEYVALUESTORECONFIG']._serialized_start=210
  _globals['_KEYVALUESTORECONFIG']._serialized_end=311
# @@protoc_insertion_point(module_scope)
