# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/extensions/filters/http/grpc_field_extraction/v3/config.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/extensions/filters/http/grpc_field_extraction/v3/config.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCenvoy/extensions/filters/http/grpc_field_extraction/v3/config.proto\x12\x36\x65nvoy.extensions.filters.http.grpc_field_extraction.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xf2\x02\n\x19GrpcFieldExtractionConfig\x12\x42\n\x0e\x64\x65scriptor_set\x18\x01 \x01(\x0b\x32 .envoy.config.core.v3.DataSourceB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x89\x01\n\x15\x65xtractions_by_method\x18\x02 \x03(\x0b\x32j.envoy.extensions.filters.http.grpc_field_extraction.v3.GrpcFieldExtractionConfig.ExtractionsByMethodEntry\x1a\x84\x01\n\x18\x45xtractionsByMethodEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12W\n\x05value\x18\x02 \x01(\x0b\x32H.envoy.extensions.filters.http.grpc_field_extraction.v3.FieldExtractions:\x02\x38\x01\"\xb4\x02\n\x10\x46ieldExtractions\x12\x88\x01\n\x19request_field_extractions\x18\x01 \x03(\x0b\x32\x65.envoy.extensions.filters.http.grpc_field_extraction.v3.FieldExtractions.RequestFieldExtractionsEntry\x1a\x94\x01\n\x1cRequestFieldExtractionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x63\n\x05value\x18\x02 \x01(\x0b\x32T.envoy.extensions.filters.http.grpc_field_extraction.v3.RequestFieldValueDisposition:\x02\x38\x01\"I\n\x1cRequestFieldValueDisposition\x12\x1a\n\x10\x64ynamic_metadata\x18\x01 \x01(\tH\x00\x42\r\n\x0b\x64ispositionB\xd4\x01\nDio.envoyproxy.envoy.extensions.filters.http.grpc_field_extraction.v3B\x0b\x43onfigProtoP\x01Zugithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/grpc_field_extraction/v3;grpc_field_extractionv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.grpc_field_extraction.v3.config_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\nDio.envoyproxy.envoy.extensions.filters.http.grpc_field_extraction.v3B\013ConfigProtoP\001Zugithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/grpc_field_extraction/v3;grpc_field_extractionv3\272\200\310\321\006\002\020\002'
  _globals['_GRPCFIELDEXTRACTIONCONFIG_EXTRACTIONSBYMETHODENTRY']._loaded_options = None
  _globals['_GRPCFIELDEXTRACTIONCONFIG_EXTRACTIONSBYMETHODENTRY']._serialized_options = b'8\001'
  _globals['_GRPCFIELDEXTRACTIONCONFIG'].fields_by_name['descriptor_set']._loaded_options = None
  _globals['_GRPCFIELDEXTRACTIONCONFIG'].fields_by_name['descriptor_set']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_FIELDEXTRACTIONS_REQUESTFIELDEXTRACTIONSENTRY']._loaded_options = None
  _globals['_FIELDEXTRACTIONS_REQUESTFIELDEXTRACTIONSENTRY']._serialized_options = b'8\001'
  _globals['_GRPCFIELDEXTRACTIONCONFIG']._serialized_start=217
  _globals['_GRPCFIELDEXTRACTIONCONFIG']._serialized_end=587
  _globals['_GRPCFIELDEXTRACTIONCONFIG_EXTRACTIONSBYMETHODENTRY']._serialized_start=455
  _globals['_GRPCFIELDEXTRACTIONCONFIG_EXTRACTIONSBYMETHODENTRY']._serialized_end=587
  _globals['_FIELDEXTRACTIONS']._serialized_start=590
  _globals['_FIELDEXTRACTIONS']._serialized_end=898
  _globals['_FIELDEXTRACTIONS_REQUESTFIELDEXTRACTIONSENTRY']._serialized_start=750
  _globals['_FIELDEXTRACTIONS_REQUESTFIELDEXTRACTIONSENTRY']._serialized_end=898
  _globals['_REQUESTFIELDVALUEDISPOSITION']._serialized_start=900
  _globals['_REQUESTFIELDVALUEDISPOSITION']._serialized_end=973
# @@protoc_insertion_point(module_scope)
