# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/extensions/filters/http/ext_proc/v3/processing_mode.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/extensions/filters/http/ext_proc/v3/processing_mode.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?envoy/extensions/filters/http/ext_proc/v3/processing_mode.proto\x12)envoy.extensions.filters.http.ext_proc.v3\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xcc\x06\n\x0eProcessingMode\x12o\n\x13request_header_mode\x18\x01 \x01(\x0e\x32H.envoy.extensions.filters.http.ext_proc.v3.ProcessingMode.HeaderSendModeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12p\n\x14response_header_mode\x18\x02 \x01(\x0e\x32H.envoy.extensions.filters.http.ext_proc.v3.ProcessingMode.HeaderSendModeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12k\n\x11request_body_mode\x18\x03 \x01(\x0e\x32\x46.envoy.extensions.filters.http.ext_proc.v3.ProcessingMode.BodySendModeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12l\n\x12response_body_mode\x18\x04 \x01(\x0e\x32\x46.envoy.extensions.filters.http.ext_proc.v3.ProcessingMode.BodySendModeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12p\n\x14request_trailer_mode\x18\x05 \x01(\x0e\x32H.envoy.extensions.filters.http.ext_proc.v3.ProcessingMode.HeaderSendModeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12q\n\x15response_trailer_mode\x18\x06 \x01(\x0e\x32H.envoy.extensions.filters.http.ext_proc.v3.ProcessingMode.HeaderSendModeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\"1\n\x0eHeaderSendMode\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x08\n\x04SEND\x10\x01\x12\x08\n\x04SKIP\x10\x02\"d\n\x0c\x42odySendMode\x12\x08\n\x04NONE\x10\x00\x12\x0c\n\x08STREAMED\x10\x01\x12\x0c\n\x08\x42UFFERED\x10\x02\x12\x14\n\x10\x42UFFERED_PARTIAL\x10\x03\x12\x18\n\x14\x46ULL_DUPLEX_STREAMED\x10\x04\x42\xb5\x01\n7io.envoyproxy.envoy.extensions.filters.http.ext_proc.v3B\x13ProcessingModeProtoP\x01Z[github.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/ext_proc/v3;ext_procv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.ext_proc.v3.processing_mode_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n7io.envoyproxy.envoy.extensions.filters.http.ext_proc.v3B\023ProcessingModeProtoP\001Z[github.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/ext_proc/v3;ext_procv3\272\200\310\321\006\002\020\002'
  _globals['_PROCESSINGMODE'].fields_by_name['request_header_mode']._loaded_options = None
  _globals['_PROCESSINGMODE'].fields_by_name['request_header_mode']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_PROCESSINGMODE'].fields_by_name['response_header_mode']._loaded_options = None
  _globals['_PROCESSINGMODE'].fields_by_name['response_header_mode']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_PROCESSINGMODE'].fields_by_name['request_body_mode']._loaded_options = None
  _globals['_PROCESSINGMODE'].fields_by_name['request_body_mode']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_PROCESSINGMODE'].fields_by_name['response_body_mode']._loaded_options = None
  _globals['_PROCESSINGMODE'].fields_by_name['response_body_mode']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_PROCESSINGMODE'].fields_by_name['request_trailer_mode']._loaded_options = None
  _globals['_PROCESSINGMODE'].fields_by_name['request_trailer_mode']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_PROCESSINGMODE'].fields_by_name['response_trailer_mode']._loaded_options = None
  _globals['_PROCESSINGMODE'].fields_by_name['response_trailer_mode']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_PROCESSINGMODE']._serialized_start=167
  _globals['_PROCESSINGMODE']._serialized_end=1011
  _globals['_PROCESSINGMODE_HEADERSENDMODE']._serialized_start=860
  _globals['_PROCESSINGMODE_HEADERSENDMODE']._serialized_end=909
  _globals['_PROCESSINGMODE_BODYSENDMODE']._serialized_start=911
  _globals['_PROCESSINGMODE_BODYSENDMODE']._serialized_end=1011
# @@protoc_insertion_point(module_scope)
