# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/config/trace/v3/datadog.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/config/trace/v3/datadog.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#envoy/config/trace/v3/datadog.proto\x12\x15\x65nvoy.config.trace.v3\x1a\x1egoogle/protobuf/duration.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"J\n\x13\x44\x61tadogRemoteConfig\x12\x33\n\x10polling_interval\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\"\xdd\x01\n\rDatadogConfig\x12\"\n\x11\x63ollector_cluster\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x1d\n\x0cservice_name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x1a\n\x12\x63ollector_hostname\x18\x03 \x01(\t\x12\x41\n\rremote_config\x18\x04 \x01(\x0b\x32*.envoy.config.trace.v3.DatadogRemoteConfig:*\x9a\xc5\x88\x1e%\n#envoy.config.trace.v2.DatadogConfigB\xb3\x01\n#io.envoyproxy.envoy.config.trace.v3B\x0c\x44\x61tadogProtoP\x01ZDgithub.com/envoyproxy/go-control-plane/envoy/config/trace/v3;tracev3\xf2\x98\xfe\x8f\x05*\x12(envoy.extensions.tracers.datadog.v4alpha\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.trace.v3.datadog_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n#io.envoyproxy.envoy.config.trace.v3B\014DatadogProtoP\001ZDgithub.com/envoyproxy/go-control-plane/envoy/config/trace/v3;tracev3\362\230\376\217\005*\022(envoy.extensions.tracers.datadog.v4alpha\272\200\310\321\006\002\020\002'
  _globals['_DATADOGCONFIG'].fields_by_name['collector_cluster']._loaded_options = None
  _globals['_DATADOGCONFIG'].fields_by_name['collector_cluster']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_DATADOGCONFIG'].fields_by_name['service_name']._loaded_options = None
  _globals['_DATADOGCONFIG'].fields_by_name['service_name']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_DATADOGCONFIG']._loaded_options = None
  _globals['_DATADOGCONFIG']._serialized_options = b'\232\305\210\036%\n#envoy.config.trace.v2.DatadogConfig'
  _globals['_DATADOGREMOTECONFIG']._serialized_start=217
  _globals['_DATADOGREMOTECONFIG']._serialized_end=291
  _globals['_DATADOGCONFIG']._serialized_start=294
  _globals['_DATADOGCONFIG']._serialized_end=515
# @@protoc_insertion_point(module_scope)
