# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/api/v2/cluster/outlier_detection.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/api/v2/cluster/outlier_detection.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,envoy/api/v2/cluster/outlier_detection.proto\x12\x14\x65nvoy.api.v2.cluster\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x9e\x0b\n\x10OutlierDetection\x12\x35\n\x0f\x63onsecutive_5xx\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x35\n\x08interval\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12?\n\x12\x62\x61se_ejection_time\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12\x43\n\x14max_ejection_percent\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\x64\x12H\n\x19\x65nforcing_consecutive_5xx\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\x64\x12\x45\n\x16\x65nforcing_success_rate\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\x64\x12@\n\x1asuccess_rate_minimum_hosts\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x41\n\x1bsuccess_rate_request_volume\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12?\n\x19success_rate_stdev_factor\x18\t \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x41\n\x1b\x63onsecutive_gateway_failure\x18\n \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12T\n%enforcing_consecutive_gateway_failure\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\x64\x12*\n\"split_external_local_origin_errors\x18\x0c \x01(\x08\x12\x46\n consecutive_local_origin_failure\x18\r \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12Y\n*enforcing_consecutive_local_origin_failure\x18\x0e \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\x64\x12R\n#enforcing_local_origin_success_rate\x18\x0f \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\x64\x12K\n\x1c\x66\x61ilure_percentage_threshold\x18\x10 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\x64\x12K\n\x1c\x65nforcing_failure_percentage\x18\x11 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\x64\x12X\n)enforcing_failure_percentage_local_origin\x18\x12 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\x64\x12\x46\n failure_percentage_minimum_hosts\x18\x13 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12G\n!failure_percentage_request_volume\x18\x14 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\xd6\x01\n\"io.envoyproxy.envoy.api.v2.clusterB\x15OutlierDetectionProtoP\x01Z;github.com/envoyproxy/go-control-plane/envoy/api/v2/cluster\xaa\x02\x16\x45nvoy.Api.V2.ClusterNS\xea\x02\x19\x45nvoy::Api::V2::ClusterNS\xf2\x98\xfe\x8f\x05\x19\x12\x17\x65nvoy.config.cluster.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.api.v2.cluster.outlier_detection_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"io.envoyproxy.envoy.api.v2.clusterB\025OutlierDetectionProtoP\001Z;github.com/envoyproxy/go-control-plane/envoy/api/v2/cluster\252\002\026Envoy.Api.V2.ClusterNS\352\002\031Envoy::Api::V2::ClusterNS\362\230\376\217\005\031\022\027envoy.config.cluster.v3\272\200\310\321\006\002\020\001'
  _globals['_OUTLIERDETECTION'].fields_by_name['interval']._loaded_options = None
  _globals['_OUTLIERDETECTION'].fields_by_name['interval']._serialized_options = b'\372B\005\252\001\002*\000'
  _globals['_OUTLIERDETECTION'].fields_by_name['base_ejection_time']._loaded_options = None
  _globals['_OUTLIERDETECTION'].fields_by_name['base_ejection_time']._serialized_options = b'\372B\005\252\001\002*\000'
  _globals['_OUTLIERDETECTION'].fields_by_name['max_ejection_percent']._loaded_options = None
  _globals['_OUTLIERDETECTION'].fields_by_name['max_ejection_percent']._serialized_options = b'\372B\004*\002\030d'
  _globals['_OUTLIERDETECTION'].fields_by_name['enforcing_consecutive_5xx']._loaded_options = None
  _globals['_OUTLIERDETECTION'].fields_by_name['enforcing_consecutive_5xx']._serialized_options = b'\372B\004*\002\030d'
  _globals['_OUTLIERDETECTION'].fields_by_name['enforcing_success_rate']._loaded_options = None
  _globals['_OUTLIERDETECTION'].fields_by_name['enforcing_success_rate']._serialized_options = b'\372B\004*\002\030d'
  _globals['_OUTLIERDETECTION'].fields_by_name['enforcing_consecutive_gateway_failure']._loaded_options = None
  _globals['_OUTLIERDETECTION'].fields_by_name['enforcing_consecutive_gateway_failure']._serialized_options = b'\372B\004*\002\030d'
  _globals['_OUTLIERDETECTION'].fields_by_name['enforcing_consecutive_local_origin_failure']._loaded_options = None
  _globals['_OUTLIERDETECTION'].fields_by_name['enforcing_consecutive_local_origin_failure']._serialized_options = b'\372B\004*\002\030d'
  _globals['_OUTLIERDETECTION'].fields_by_name['enforcing_local_origin_success_rate']._loaded_options = None
  _globals['_OUTLIERDETECTION'].fields_by_name['enforcing_local_origin_success_rate']._serialized_options = b'\372B\004*\002\030d'
  _globals['_OUTLIERDETECTION'].fields_by_name['failure_percentage_threshold']._loaded_options = None
  _globals['_OUTLIERDETECTION'].fields_by_name['failure_percentage_threshold']._serialized_options = b'\372B\004*\002\030d'
  _globals['_OUTLIERDETECTION'].fields_by_name['enforcing_failure_percentage']._loaded_options = None
  _globals['_OUTLIERDETECTION'].fields_by_name['enforcing_failure_percentage']._serialized_options = b'\372B\004*\002\030d'
  _globals['_OUTLIERDETECTION'].fields_by_name['enforcing_failure_percentage_local_origin']._loaded_options = None
  _globals['_OUTLIERDETECTION'].fields_by_name['enforcing_failure_percentage_local_origin']._serialized_options = b'\372B\004*\002\030d'
  _globals['_OUTLIERDETECTION']._serialized_start=223
  _globals['_OUTLIERDETECTION']._serialized_end=1661
# @@protoc_insertion_point(module_scope)
