# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/config/bootstrap/v3/bootstrap.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/config/bootstrap/v3/bootstrap.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.accesslog.v3 import accesslog_pb2 as envoy_dot_config_dot_accesslog_dot_v3_dot_accesslog__pb2
from envoy.config.cluster.v3 import cluster_pb2 as envoy_dot_config_dot_cluster_dot_v3_dot_cluster__pb2
from envoy.config.core.v3 import address_pb2 as envoy_dot_config_dot_core_dot_v3_dot_address__pb2
from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.config.core.v3 import config_source_pb2 as envoy_dot_config_dot_core_dot_v3_dot_config__source__pb2
from envoy.config.core.v3 import event_service_config_pb2 as envoy_dot_config_dot_core_dot_v3_dot_event__service__config__pb2
from envoy.config.core.v3 import extension_pb2 as envoy_dot_config_dot_core_dot_v3_dot_extension__pb2
from envoy.config.core.v3 import resolver_pb2 as envoy_dot_config_dot_core_dot_v3_dot_resolver__pb2
from envoy.config.core.v3 import socket_option_pb2 as envoy_dot_config_dot_core_dot_v3_dot_socket__option__pb2
from envoy.config.listener.v3 import listener_pb2 as envoy_dot_config_dot_listener_dot_v3_dot_listener__pb2
from envoy.config.metrics.v3 import stats_pb2 as envoy_dot_config_dot_metrics_dot_v3_dot_stats__pb2
from envoy.config.overload.v3 import overload_pb2 as envoy_dot_config_dot_overload_dot_v3_dot_overload__pb2
from envoy.config.trace.v3 import http_tracer_pb2 as envoy_dot_config_dot_trace_dot_v3_dot_http__tracer__pb2
from envoy.extensions.transport_sockets.tls.v3 import secret_pb2 as envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v3_dot_secret__pb2
from envoy.type.v3 import percent_pb2 as envoy_dot_type_dot_v3_dot_percent__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import security_pb2 as udpa_dot_annotations_dot_security__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)envoy/config/bootstrap/v3/bootstrap.proto\x12\x19\x65nvoy.config.bootstrap.v3\x1a)envoy/config/accesslog/v3/accesslog.proto\x1a%envoy/config/cluster/v3/cluster.proto\x1a\"envoy/config/core/v3/address.proto\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a(envoy/config/core/v3/config_source.proto\x1a/envoy/config/core/v3/event_service_config.proto\x1a$envoy/config/core/v3/extension.proto\x1a#envoy/config/core/v3/resolver.proto\x1a(envoy/config/core/v3/socket_option.proto\x1a\'envoy/config/listener/v3/listener.proto\x1a#envoy/config/metrics/v3/stats.proto\x1a\'envoy/config/overload/v3/overload.proto\x1a\'envoy/config/trace/v3/http_tracer.proto\x1a\x36\x65nvoy/extensions/transport_sockets/tls/v3/secret.proto\x1a\x1b\x65nvoy/type/v3/percent.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1fudpa/annotations/security.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x82\x1d\n\tBootstrap\x12(\n\x04node\x18\x01 \x01(\x0b\x32\x1a.envoy.config.core.v3.Node\x12\x1b\n\x13node_context_params\x18\x1a \x03(\t\x12N\n\x10static_resources\x18\x02 \x01(\x0b\x32\x34.envoy.config.bootstrap.v3.Bootstrap.StaticResources\x12P\n\x11\x64ynamic_resources\x18\x03 \x01(\x0b\x32\x35.envoy.config.bootstrap.v3.Bootstrap.DynamicResources\x12\x42\n\x0f\x63luster_manager\x18\x04 \x01(\x0b\x32).envoy.config.bootstrap.v3.ClusterManager\x12\x39\n\nhds_config\x18\x0e \x01(\x0b\x32%.envoy.config.core.v3.ApiConfigSource\x12\x12\n\nflags_path\x18\x05 \x01(\t\x12\x37\n\x0bstats_sinks\x18\x06 \x03(\x0b\x32\".envoy.config.metrics.v3.StatsSink\x12W\n\x15\x64\x65\x66\x65rred_stat_options\x18\' \x01(\x0b\x32\x38.envoy.config.bootstrap.v3.Bootstrap.DeferredStatOptions\x12:\n\x0cstats_config\x18\r \x01(\x0b\x32$.envoy.config.metrics.v3.StatsConfig\x12]\n\x14stats_flush_interval\x18\x07 \x01(\x0b\x32\x19.google.protobuf.DurationB$\xfa\x42\x0e\xaa\x01\x0b\x1a\x03\x08\xac\x02\x32\x04\x10\xc0\x84=\xf2\x98\xfe\x8f\x05\r\x12\x0bstats_flush\x12\'\n\x14stats_flush_on_admin\x18\x1d \x01(\x08\x42\x07\xfa\x42\x04j\x02\x08\x01H\x00\x12\x42\n\x08watchdog\x18\x08 \x01(\x0b\x32#.envoy.config.bootstrap.v3.WatchdogB\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0\x12\x37\n\twatchdogs\x18\x1b \x01(\x0b\x32$.envoy.config.bootstrap.v3.Watchdogs\x12<\n\x07tracing\x18\t \x01(\x0b\x32\x1e.envoy.config.trace.v3.TracingB\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0\x12\x42\n\x0flayered_runtime\x18\x11 \x01(\x0b\x32).envoy.config.bootstrap.v3.LayeredRuntime\x12/\n\x05\x61\x64min\x18\x0c \x01(\x0b\x32 .envoy.config.bootstrap.v3.Admin\x12N\n\x10overload_manager\x18\x0f \x01(\x0b\x32).envoy.config.overload.v3.OverloadManagerB\t\x8a\x93\xb7*\x04\x08\x01\x10\x01\x12\x1f\n\x17\x65nable_dispatcher_stats\x18\x10 \x01(\x08\x12\x15\n\rheader_prefix\x18\x12 \x01(\t\x12\x43\n\x1dstats_server_version_override\x18\x13 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12,\n\x17use_tcp_for_dns_lookups\x18\x14 \x01(\x08\x42\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0\x12U\n\x15\x64ns_resolution_config\x18\x1e \x01(\x0b\x32).envoy.config.core.v3.DnsResolutionConfigB\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0\x12M\n\x19typed_dns_resolver_config\x18\x1f \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfig\x12H\n\x14\x62ootstrap_extensions\x18\x15 \x03(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfig\x12=\n\rfatal_actions\x18\x1c \x03(\x0b\x32&.envoy.config.bootstrap.v3.FatalAction\x12:\n\x0e\x63onfig_sources\x18\x16 \x03(\x0b\x32\".envoy.config.core.v3.ConfigSource\x12\x41\n\x15\x64\x65\x66\x61ult_config_source\x18\x17 \x01(\x0b\x32\".envoy.config.core.v3.ConfigSource\x12 \n\x18\x64\x65\x66\x61ult_socket_interface\x18\x18 \x01(\t\x12n\n\x1e\x63\x65rtificate_provider_instances\x18\x19 \x03(\x0b\x32\x46.envoy.config.bootstrap.v3.Bootstrap.CertificateProviderInstancesEntry\x12\x45\n\x0einline_headers\x18  \x03(\x0b\x32-.envoy.config.bootstrap.v3.CustomInlineHeader\x12\x1e\n\x16perf_tracing_file_path\x18! \x01(\t\x12H\n\x14\x64\x65\x66\x61ult_regex_engine\x18\" \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfig\x12J\n\x16xds_delegate_extension\x18# \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfig\x12P\n\x1cxds_config_tracker_extension\x18$ \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfig\x12\x44\n\x10listener_manager\x18% \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfig\x12Y\n\x16\x61pplication_log_config\x18& \x01(\x0b\x32\x39.envoy.config.bootstrap.v3.Bootstrap.ApplicationLogConfig\x12k\n grpc_async_client_manager_config\x18( \x01(\x0b\x32\x41.envoy.config.bootstrap.v3.Bootstrap.GrpcAsyncClientManagerConfig\x12S\n\x18memory_allocator_manager\x18) \x01(\x0b\x32\x31.envoy.config.bootstrap.v3.MemoryAllocatorManager\x1a\xfc\x01\n\x0fStaticResources\x12\x35\n\tlisteners\x18\x01 \x03(\x0b\x32\".envoy.config.listener.v3.Listener\x12\x32\n\x08\x63lusters\x18\x02 \x03(\x0b\x32 .envoy.config.cluster.v3.Cluster\x12\x42\n\x07secrets\x18\x03 \x03(\x0b\x32\x31.envoy.extensions.transport_sockets.tls.v3.Secret::\x9a\xc5\x88\x1e\x35\n3envoy.config.bootstrap.v2.Bootstrap.StaticResources\x1a\xbe\x02\n\x10\x44ynamicResources\x12\x36\n\nlds_config\x18\x01 \x01(\x0b\x32\".envoy.config.core.v3.ConfigSource\x12\x1d\n\x15lds_resources_locator\x18\x05 \x01(\t\x12\x36\n\ncds_config\x18\x02 \x01(\x0b\x32\".envoy.config.core.v3.ConfigSource\x12\x1d\n\x15\x63\x64s_resources_locator\x18\x06 \x01(\t\x12\x39\n\nads_config\x18\x03 \x01(\x0b\x32%.envoy.config.core.v3.ApiConfigSource:;\x9a\xc5\x88\x1e\x36\n4envoy.config.bootstrap.v2.Bootstrap.DynamicResourcesJ\x04\x08\x04\x10\x05\x1a\xd6\x01\n\x14\x41pplicationLogConfig\x12W\n\nlog_format\x18\x01 \x01(\x0b\x32\x43.envoy.config.bootstrap.v3.Bootstrap.ApplicationLogConfig.LogFormat\x1a\x65\n\tLogFormat\x12.\n\x0bjson_format\x18\x01 \x01(\x0b\x32\x17.google.protobuf.StructH\x00\x12\x15\n\x0btext_format\x18\x02 \x01(\tH\x00\x42\x11\n\nlog_format\x12\x03\xf8\x42\x01\x1a=\n\x13\x44\x65\x66\x65rredStatOptions\x12&\n\x1e\x65nable_deferred_creation_stats\x18\x01 \x01(\x08\x1am\n\x1cGrpcAsyncClientManagerConfig\x12M\n\x1emax_cached_entry_idle_duration\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\x42\x07\xaa\x01\x04\x32\x02\x08\x05\x1ao\n!CertificateProviderInstancesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x39\n\x05value\x18\x02 \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfig:\x02\x38\x01:*\x9a\xc5\x88\x1e%\n#envoy.config.bootstrap.v2.BootstrapB\r\n\x0bstats_flushJ\x04\x08\n\x10\x0bJ\x04\x08\x0b\x10\x0cR\x07runtime\"\xb3\x02\n\x05\x41\x64min\x12\x38\n\naccess_log\x18\x05 \x03(\x0b\x32$.envoy.config.accesslog.v3.AccessLog\x12$\n\x0f\x61\x63\x63\x65ss_log_path\x18\x01 \x01(\tB\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0\x12\x14\n\x0cprofile_path\x18\x02 \x01(\t\x12.\n\x07\x61\x64\x64ress\x18\x03 \x01(\x0b\x32\x1d.envoy.config.core.v3.Address\x12:\n\x0esocket_options\x18\x04 \x03(\x0b\x32\".envoy.config.core.v3.SocketOption\x12 \n\x18ignore_global_conn_limit\x18\x06 \x01(\x08:&\x9a\xc5\x88\x1e!\n\x1f\x65nvoy.config.bootstrap.v2.Admin\"\x90\x04\n\x0e\x43lusterManager\x12\x1a\n\x12local_cluster_name\x18\x01 \x01(\t\x12U\n\x11outlier_detection\x18\x02 \x01(\x0b\x32:.envoy.config.bootstrap.v3.ClusterManager.OutlierDetection\x12>\n\x14upstream_bind_config\x18\x03 \x01(\x0b\x32 .envoy.config.core.v3.BindConfig\x12@\n\x11load_stats_config\x18\x04 \x01(\x0b\x32%.envoy.config.core.v3.ApiConfigSource\x12(\n enable_deferred_cluster_creation\x18\x05 \x01(\x08\x1a\xad\x01\n\x10OutlierDetection\x12\x16\n\x0e\x65vent_log_path\x18\x01 \x01(\t\x12?\n\revent_service\x18\x02 \x01(\x0b\x32(.envoy.config.core.v3.EventServiceConfig:@\x9a\xc5\x88\x1e;\n9envoy.config.bootstrap.v2.ClusterManager.OutlierDetection:/\x9a\xc5\x88\x1e*\n(envoy.config.bootstrap.v2.ClusterManager\"\x8c\x01\n\tWatchdogs\x12\x41\n\x14main_thread_watchdog\x18\x01 \x01(\x0b\x32#.envoy.config.bootstrap.v3.Watchdog\x12<\n\x0fworker_watchdog\x18\x02 \x01(\x0b\x32#.envoy.config.bootstrap.v3.Watchdog\"\xbb\x05\n\x08Watchdog\x12\x43\n\x07\x61\x63tions\x18\x07 \x03(\x0b\x32\x32.envoy.config.bootstrap.v3.Watchdog.WatchdogAction\x12/\n\x0cmiss_timeout\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x33\n\x10megamiss_timeout\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12/\n\x0ckill_timeout\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x44\n\x17max_kill_timeout_jitter\x18\x06 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02\x32\x00\x12\x34\n\x11multikill_timeout\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x33\n\x13multikill_threshold\x18\x05 \x01(\x0b\x32\x16.envoy.type.v3.Percent\x1a\xf6\x01\n\x0eWatchdogAction\x12:\n\x06\x63onfig\x18\x01 \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfig\x12Y\n\x05\x65vent\x18\x02 \x01(\x0e\x32@.envoy.config.bootstrap.v3.Watchdog.WatchdogAction.WatchdogEventB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\"M\n\rWatchdogEvent\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04KILL\x10\x01\x12\r\n\tMULTIKILL\x10\x02\x12\x0c\n\x08MEGAMISS\x10\x03\x12\x08\n\x04MISS\x10\x04:)\x9a\xc5\x88\x1e$\n\"envoy.config.bootstrap.v2.Watchdog\"I\n\x0b\x46\x61talAction\x12:\n\x06\x63onfig\x18\x01 \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfig\"\xa5\x01\n\x07Runtime\x12\x14\n\x0csymlink_root\x18\x01 \x01(\t\x12\x14\n\x0csubdirectory\x18\x02 \x01(\t\x12\x1d\n\x15override_subdirectory\x18\x03 \x01(\t\x12%\n\x04\x62\x61se\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct:(\x9a\xc5\x88\x1e#\n!envoy.config.bootstrap.v2.Runtime\"\xe3\x05\n\x0cRuntimeLayer\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12/\n\x0cstatic_layer\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructH\x00\x12G\n\ndisk_layer\x18\x03 \x01(\x0b\x32\x31.envoy.config.bootstrap.v3.RuntimeLayer.DiskLayerH\x00\x12I\n\x0b\x61\x64min_layer\x18\x04 \x01(\x0b\x32\x32.envoy.config.bootstrap.v3.RuntimeLayer.AdminLayerH\x00\x12G\n\nrtds_layer\x18\x05 \x01(\x0b\x32\x31.envoy.config.bootstrap.v3.RuntimeLayer.RtdsLayerH\x00\x1a\x90\x01\n\tDiskLayer\x12\x14\n\x0csymlink_root\x18\x01 \x01(\t\x12\x14\n\x0csubdirectory\x18\x03 \x01(\t\x12\x1e\n\x16\x61ppend_service_cluster\x18\x02 \x01(\x08:7\x9a\xc5\x88\x1e\x32\n0envoy.config.bootstrap.v2.RuntimeLayer.DiskLayer\x1a\x46\n\nAdminLayer:8\x9a\xc5\x88\x1e\x33\n1envoy.config.bootstrap.v2.RuntimeLayer.AdminLayer\x1a\x8b\x01\n\tRtdsLayer\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x37\n\x0brtds_config\x18\x02 \x01(\x0b\x32\".envoy.config.core.v3.ConfigSource:7\x9a\xc5\x88\x1e\x32\n0envoy.config.bootstrap.v2.RuntimeLayer.RtdsLayer:-\x9a\xc5\x88\x1e(\n&envoy.config.bootstrap.v2.RuntimeLayerB\x16\n\x0flayer_specifier\x12\x03\xf8\x42\x01\"z\n\x0eLayeredRuntime\x12\x37\n\x06layers\x18\x01 \x03(\x0b\x32\'.envoy.config.bootstrap.v3.RuntimeLayer:/\x9a\xc5\x88\x1e*\n(envoy.config.bootstrap.v2.LayeredRuntime\"\x8d\x02\n\x12\x43ustomInlineHeader\x12)\n\x12inline_header_name\x18\x01 \x01(\tB\r\xfa\x42\nr\x08\x10\x01\xc0\x01\x01\xc8\x01\x00\x12\x64\n\x12inline_header_type\x18\x02 \x01(\x0e\x32>.envoy.config.bootstrap.v3.CustomInlineHeader.InlineHeaderTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\"f\n\x10InlineHeaderType\x12\x12\n\x0eREQUEST_HEADER\x10\x00\x12\x13\n\x0fREQUEST_TRAILER\x10\x01\x12\x13\n\x0fRESPONSE_HEADER\x10\x02\x12\x14\n\x10RESPONSE_TRAILER\x10\x03\"n\n\x16MemoryAllocatorManager\x12\x18\n\x10\x62ytes_to_release\x18\x01 \x01(\x04\x12:\n\x17memory_release_interval\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x91\x01\n\'io.envoyproxy.envoy.config.bootstrap.v3B\x0e\x42ootstrapProtoP\x01ZLgithub.com/envoyproxy/go-control-plane/envoy/config/bootstrap/v3;bootstrapv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.bootstrap.v3.bootstrap_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\'io.envoyproxy.envoy.config.bootstrap.v3B\016BootstrapProtoP\001ZLgithub.com/envoyproxy/go-control-plane/envoy/config/bootstrap/v3;bootstrapv3\272\200\310\321\006\002\020\002'
  _globals['_BOOTSTRAP_STATICRESOURCES']._loaded_options = None
  _globals['_BOOTSTRAP_STATICRESOURCES']._serialized_options = b'\232\305\210\0365\n3envoy.config.bootstrap.v2.Bootstrap.StaticResources'
  _globals['_BOOTSTRAP_DYNAMICRESOURCES']._loaded_options = None
  _globals['_BOOTSTRAP_DYNAMICRESOURCES']._serialized_options = b'\232\305\210\0366\n4envoy.config.bootstrap.v2.Bootstrap.DynamicResources'
  _globals['_BOOTSTRAP_APPLICATIONLOGCONFIG_LOGFORMAT'].oneofs_by_name['log_format']._loaded_options = None
  _globals['_BOOTSTRAP_APPLICATIONLOGCONFIG_LOGFORMAT'].oneofs_by_name['log_format']._serialized_options = b'\370B\001'
  _globals['_BOOTSTRAP_GRPCASYNCCLIENTMANAGERCONFIG'].fields_by_name['max_cached_entry_idle_duration']._loaded_options = None
  _globals['_BOOTSTRAP_GRPCASYNCCLIENTMANAGERCONFIG'].fields_by_name['max_cached_entry_idle_duration']._serialized_options = b'\372B\007\252\001\0042\002\010\005'
  _globals['_BOOTSTRAP_CERTIFICATEPROVIDERINSTANCESENTRY']._loaded_options = None
  _globals['_BOOTSTRAP_CERTIFICATEPROVIDERINSTANCESENTRY']._serialized_options = b'8\001'
  _globals['_BOOTSTRAP'].fields_by_name['stats_flush_interval']._loaded_options = None
  _globals['_BOOTSTRAP'].fields_by_name['stats_flush_interval']._serialized_options = b'\372B\016\252\001\013\032\003\010\254\0022\004\020\300\204=\362\230\376\217\005\r\022\013stats_flush'
  _globals['_BOOTSTRAP'].fields_by_name['stats_flush_on_admin']._loaded_options = None
  _globals['_BOOTSTRAP'].fields_by_name['stats_flush_on_admin']._serialized_options = b'\372B\004j\002\010\001'
  _globals['_BOOTSTRAP'].fields_by_name['watchdog']._loaded_options = None
  _globals['_BOOTSTRAP'].fields_by_name['watchdog']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _globals['_BOOTSTRAP'].fields_by_name['tracing']._loaded_options = None
  _globals['_BOOTSTRAP'].fields_by_name['tracing']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _globals['_BOOTSTRAP'].fields_by_name['overload_manager']._loaded_options = None
  _globals['_BOOTSTRAP'].fields_by_name['overload_manager']._serialized_options = b'\212\223\267*\004\010\001\020\001'
  _globals['_BOOTSTRAP'].fields_by_name['use_tcp_for_dns_lookups']._loaded_options = None
  _globals['_BOOTSTRAP'].fields_by_name['use_tcp_for_dns_lookups']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _globals['_BOOTSTRAP'].fields_by_name['dns_resolution_config']._loaded_options = None
  _globals['_BOOTSTRAP'].fields_by_name['dns_resolution_config']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _globals['_BOOTSTRAP']._loaded_options = None
  _globals['_BOOTSTRAP']._serialized_options = b'\232\305\210\036%\n#envoy.config.bootstrap.v2.Bootstrap'
  _globals['_ADMIN'].fields_by_name['access_log_path']._loaded_options = None
  _globals['_ADMIN'].fields_by_name['access_log_path']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _globals['_ADMIN']._loaded_options = None
  _globals['_ADMIN']._serialized_options = b'\232\305\210\036!\n\037envoy.config.bootstrap.v2.Admin'
  _globals['_CLUSTERMANAGER_OUTLIERDETECTION']._loaded_options = None
  _globals['_CLUSTERMANAGER_OUTLIERDETECTION']._serialized_options = b'\232\305\210\036;\n9envoy.config.bootstrap.v2.ClusterManager.OutlierDetection'
  _globals['_CLUSTERMANAGER']._loaded_options = None
  _globals['_CLUSTERMANAGER']._serialized_options = b'\232\305\210\036*\n(envoy.config.bootstrap.v2.ClusterManager'
  _globals['_WATCHDOG_WATCHDOGACTION'].fields_by_name['event']._loaded_options = None
  _globals['_WATCHDOG_WATCHDOGACTION'].fields_by_name['event']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_WATCHDOG'].fields_by_name['max_kill_timeout_jitter']._loaded_options = None
  _globals['_WATCHDOG'].fields_by_name['max_kill_timeout_jitter']._serialized_options = b'\372B\005\252\001\0022\000'
  _globals['_WATCHDOG']._loaded_options = None
  _globals['_WATCHDOG']._serialized_options = b'\232\305\210\036$\n\"envoy.config.bootstrap.v2.Watchdog'
  _globals['_RUNTIME']._loaded_options = None
  _globals['_RUNTIME']._serialized_options = b'\232\305\210\036#\n!envoy.config.bootstrap.v2.Runtime'
  _globals['_RUNTIMELAYER_DISKLAYER']._loaded_options = None
  _globals['_RUNTIMELAYER_DISKLAYER']._serialized_options = b'\232\305\210\0362\n0envoy.config.bootstrap.v2.RuntimeLayer.DiskLayer'
  _globals['_RUNTIMELAYER_ADMINLAYER']._loaded_options = None
  _globals['_RUNTIMELAYER_ADMINLAYER']._serialized_options = b'\232\305\210\0363\n1envoy.config.bootstrap.v2.RuntimeLayer.AdminLayer'
  _globals['_RUNTIMELAYER_RTDSLAYER']._loaded_options = None
  _globals['_RUNTIMELAYER_RTDSLAYER']._serialized_options = b'\232\305\210\0362\n0envoy.config.bootstrap.v2.RuntimeLayer.RtdsLayer'
  _globals['_RUNTIMELAYER'].oneofs_by_name['layer_specifier']._loaded_options = None
  _globals['_RUNTIMELAYER'].oneofs_by_name['layer_specifier']._serialized_options = b'\370B\001'
  _globals['_RUNTIMELAYER'].fields_by_name['name']._loaded_options = None
  _globals['_RUNTIMELAYER'].fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_RUNTIMELAYER']._loaded_options = None
  _globals['_RUNTIMELAYER']._serialized_options = b'\232\305\210\036(\n&envoy.config.bootstrap.v2.RuntimeLayer'
  _globals['_LAYEREDRUNTIME']._loaded_options = None
  _globals['_LAYEREDRUNTIME']._serialized_options = b'\232\305\210\036*\n(envoy.config.bootstrap.v2.LayeredRuntime'
  _globals['_CUSTOMINLINEHEADER'].fields_by_name['inline_header_name']._loaded_options = None
  _globals['_CUSTOMINLINEHEADER'].fields_by_name['inline_header_name']._serialized_options = b'\372B\nr\010\020\001\300\001\001\310\001\000'
  _globals['_CUSTOMINLINEHEADER'].fields_by_name['inline_header_type']._loaded_options = None
  _globals['_CUSTOMINLINEHEADER'].fields_by_name['inline_header_type']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_BOOTSTRAP']._serialized_start=964
  _globals['_BOOTSTRAP']._serialized_end=4678
  _globals['_BOOTSTRAP_STATICRESOURCES']._serialized_start=3521
  _globals['_BOOTSTRAP_STATICRESOURCES']._serialized_end=3773
  _globals['_BOOTSTRAP_DYNAMICRESOURCES']._serialized_start=3776
  _globals['_BOOTSTRAP_DYNAMICRESOURCES']._serialized_end=4094
  _globals['_BOOTSTRAP_APPLICATIONLOGCONFIG']._serialized_start=4097
  _globals['_BOOTSTRAP_APPLICATIONLOGCONFIG']._serialized_end=4311
  _globals['_BOOTSTRAP_APPLICATIONLOGCONFIG_LOGFORMAT']._serialized_start=4210
  _globals['_BOOTSTRAP_APPLICATIONLOGCONFIG_LOGFORMAT']._serialized_end=4311
  _globals['_BOOTSTRAP_DEFERREDSTATOPTIONS']._serialized_start=4313
  _globals['_BOOTSTRAP_DEFERREDSTATOPTIONS']._serialized_end=4374
  _globals['_BOOTSTRAP_GRPCASYNCCLIENTMANAGERCONFIG']._serialized_start=4376
  _globals['_BOOTSTRAP_GRPCASYNCCLIENTMANAGERCONFIG']._serialized_end=4485
  _globals['_BOOTSTRAP_CERTIFICATEPROVIDERINSTANCESENTRY']._serialized_start=4487
  _globals['_BOOTSTRAP_CERTIFICATEPROVIDERINSTANCESENTRY']._serialized_end=4598
  _globals['_ADMIN']._serialized_start=4681
  _globals['_ADMIN']._serialized_end=4988
  _globals['_CLUSTERMANAGER']._serialized_start=4991
  _globals['_CLUSTERMANAGER']._serialized_end=5519
  _globals['_CLUSTERMANAGER_OUTLIERDETECTION']._serialized_start=5297
  _globals['_CLUSTERMANAGER_OUTLIERDETECTION']._serialized_end=5470
  _globals['_WATCHDOGS']._serialized_start=5522
  _globals['_WATCHDOGS']._serialized_end=5662
  _globals['_WATCHDOG']._serialized_start=5665
  _globals['_WATCHDOG']._serialized_end=6364
  _globals['_WATCHDOG_WATCHDOGACTION']._serialized_start=6075
  _globals['_WATCHDOG_WATCHDOGACTION']._serialized_end=6321
  _globals['_WATCHDOG_WATCHDOGACTION_WATCHDOGEVENT']._serialized_start=6244
  _globals['_WATCHDOG_WATCHDOGACTION_WATCHDOGEVENT']._serialized_end=6321
  _globals['_FATALACTION']._serialized_start=6366
  _globals['_FATALACTION']._serialized_end=6439
  _globals['_RUNTIME']._serialized_start=6442
  _globals['_RUNTIME']._serialized_end=6607
  _globals['_RUNTIMELAYER']._serialized_start=6610
  _globals['_RUNTIMELAYER']._serialized_end=7349
  _globals['_RUNTIMELAYER_DISKLAYER']._serialized_start=6920
  _globals['_RUNTIMELAYER_DISKLAYER']._serialized_end=7064
  _globals['_RUNTIMELAYER_ADMINLAYER']._serialized_start=7066
  _globals['_RUNTIMELAYER_ADMINLAYER']._serialized_end=7136
  _globals['_RUNTIMELAYER_RTDSLAYER']._serialized_start=7139
  _globals['_RUNTIMELAYER_RTDSLAYER']._serialized_end=7278
  _globals['_LAYEREDRUNTIME']._serialized_start=7351
  _globals['_LAYEREDRUNTIME']._serialized_end=7473
  _globals['_CUSTOMINLINEHEADER']._serialized_start=7476
  _globals['_CUSTOMINLINEHEADER']._serialized_end=7745
  _globals['_CUSTOMINLINEHEADER_INLINEHEADERTYPE']._serialized_start=7643
  _globals['_CUSTOMINLINEHEADER_INLINEHEADERTYPE']._serialized_end=7745
  _globals['_MEMORYALLOCATORMANAGER']._serialized_start=7747
  _globals['_MEMORYALLOCATORMANAGER']._serialized_end=7857
# @@protoc_insertion_point(module_scope)
