# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/extensions/filters/http/json_to_metadata/v3/json_to_metadata.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/extensions/filters/http/json_to_metadata/v3/json_to_metadata.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.type.matcher.v3 import regex_pb2 as envoy_dot_type_dot_matcher_dot_v3_dot_regex__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHenvoy/extensions/filters/http/json_to_metadata/v3/json_to_metadata.proto\x12\x31\x65nvoy.extensions.filters.http.json_to_metadata.v3\x1a!envoy/type/matcher/v3/regex.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xee\t\n\x0eJsonToMetadata\x12\x63\n\rrequest_rules\x18\x01 \x01(\x0b\x32L.envoy.extensions.filters.http.json_to_metadata.v3.JsonToMetadata.MatchRules\x12\x64\n\x0eresponse_rules\x18\x02 \x01(\x0b\x32L.envoy.extensions.filters.http.json_to_metadata.v3.JsonToMetadata.MatchRules\x1a\x86\x02\n\x0cKeyValuePair\x12\x1a\n\x12metadata_namespace\x18\x01 \x01(\t\x12\x14\n\x03key\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\'\n\x05value\x18\x03 \x01(\x0b\x32\x16.google.protobuf.ValueH\x00\x12\x63\n\x04type\x18\x04 \x01(\x0e\x32K.envoy.extensions.filters.http.json_to_metadata.v3.JsonToMetadata.ValueTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12(\n preserve_existing_metadata_value\x18\x05 \x01(\x08\x42\x0c\n\nvalue_type\x1a.\n\x08Selector\x12\x16\n\x03key\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00\x42\n\n\x08selector\x1a\x99\x03\n\x04Rule\x12g\n\tselectors\x18\x01 \x03(\x0b\x32J.envoy.extensions.filters.http.json_to_metadata.v3.JsonToMetadata.SelectorB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x12\x62\n\non_present\x18\x02 \x01(\x0b\x32N.envoy.extensions.filters.http.json_to_metadata.v3.JsonToMetadata.KeyValuePair\x12\x62\n\non_missing\x18\x03 \x01(\x0b\x32N.envoy.extensions.filters.http.json_to_metadata.v3.JsonToMetadata.KeyValuePair\x12`\n\x08on_error\x18\x04 \x01(\x0b\x32N.envoy.extensions.filters.http.json_to_metadata.v3.JsonToMetadata.KeyValuePair\x1a\x82\x02\n\nMatchRules\x12_\n\x05rules\x18\x01 \x03(\x0b\x32\x46.envoy.extensions.filters.http.json_to_metadata.v3.JsonToMetadata.RuleB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x12)\n\x13\x61llow_content_types\x18\x02 \x03(\tB\x0c\xfa\x42\t\x92\x01\x06\"\x04r\x02\x10\x01\x12 \n\x18\x61llow_empty_content_type\x18\x03 \x01(\x08\x12\x46\n\x19\x61llow_content_types_regex\x18\x04 \x01(\x0b\x32#.envoy.type.matcher.v3.RegexMatcher\"7\n\tValueType\x12\x12\n\x0ePROTOBUF_VALUE\x10\x00\x12\n\n\x06STRING\x10\x01\x12\n\n\x06NUMBER\x10\x02\x42\xcd\x01\n?io.envoyproxy.envoy.extensions.filters.http.json_to_metadata.v3B\x13JsonToMetadataProtoP\x01Zkgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/json_to_metadata/v3;json_to_metadatav3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.json_to_metadata.v3.json_to_metadata_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n?io.envoyproxy.envoy.extensions.filters.http.json_to_metadata.v3B\023JsonToMetadataProtoP\001Zkgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/json_to_metadata/v3;json_to_metadatav3\272\200\310\321\006\002\020\002'
  _globals['_JSONTOMETADATA_KEYVALUEPAIR'].fields_by_name['key']._loaded_options = None
  _globals['_JSONTOMETADATA_KEYVALUEPAIR'].fields_by_name['key']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_JSONTOMETADATA_KEYVALUEPAIR'].fields_by_name['type']._loaded_options = None
  _globals['_JSONTOMETADATA_KEYVALUEPAIR'].fields_by_name['type']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_JSONTOMETADATA_SELECTOR'].fields_by_name['key']._loaded_options = None
  _globals['_JSONTOMETADATA_SELECTOR'].fields_by_name['key']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_JSONTOMETADATA_RULE'].fields_by_name['selectors']._loaded_options = None
  _globals['_JSONTOMETADATA_RULE'].fields_by_name['selectors']._serialized_options = b'\372B\005\222\001\002\010\001'
  _globals['_JSONTOMETADATA_MATCHRULES'].fields_by_name['rules']._loaded_options = None
  _globals['_JSONTOMETADATA_MATCHRULES'].fields_by_name['rules']._serialized_options = b'\372B\005\222\001\002\010\001'
  _globals['_JSONTOMETADATA_MATCHRULES'].fields_by_name['allow_content_types']._loaded_options = None
  _globals['_JSONTOMETADATA_MATCHRULES'].fields_by_name['allow_content_types']._serialized_options = b'\372B\t\222\001\006\"\004r\002\020\001'
  _globals['_JSONTOMETADATA']._serialized_start=249
  _globals['_JSONTOMETADATA']._serialized_end=1511
  _globals['_JSONTOMETADATA_KEYVALUEPAIR']._serialized_start=471
  _globals['_JSONTOMETADATA_KEYVALUEPAIR']._serialized_end=733
  _globals['_JSONTOMETADATA_SELECTOR']._serialized_start=735
  _globals['_JSONTOMETADATA_SELECTOR']._serialized_end=781
  _globals['_JSONTOMETADATA_RULE']._serialized_start=784
  _globals['_JSONTOMETADATA_RULE']._serialized_end=1193
  _globals['_JSONTOMETADATA_MATCHRULES']._serialized_start=1196
  _globals['_JSONTOMETADATA_MATCHRULES']._serialized_end=1454
  _globals['_JSONTOMETADATA_VALUETYPE']._serialized_start=1456
  _globals['_JSONTOMETADATA_VALUETYPE']._serialized_end=1511
# @@protoc_insertion_point(module_scope)
