# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/extensions/filters/common/fault/v3/fault.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/extensions/filters/common/fault/v3/fault.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.type.v3 import percent_pb2 as envoy_dot_type_dot_v3_dot_percent__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4envoy/extensions/filters/common/fault/v3/fault.proto\x12(envoy.extensions.filters.common.fault.v3\x1a\x1b\x65nvoy/type/v3/percent.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x9f\x03\n\nFaultDelay\x12:\n\x0b\x66ixed_delay\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00H\x00\x12X\n\x0cheader_delay\x18\x05 \x01(\x0b\x32@.envoy.extensions.filters.common.fault.v3.FaultDelay.HeaderDelayH\x00\x12\x34\n\npercentage\x18\x04 \x01(\x0b\x32 .envoy.type.v3.FractionalPercent\x1aI\n\x0bHeaderDelay::\x9a\xc5\x88\x1e\x35\n3envoy.config.filter.fault.v2.FaultDelay.HeaderDelay\"\x1b\n\x0e\x46\x61ultDelayType\x12\t\n\x05\x46IXED\x10\x00:.\x9a\xc5\x88\x1e)\n\'envoy.config.filter.fault.v2.FaultDelayB\x1b\n\x14\x66\x61ult_delay_secifier\x12\x03\xf8\x42\x01J\x04\x08\x02\x10\x03J\x04\x08\x01\x10\x02R\x04type\"\x80\x04\n\x0e\x46\x61ultRateLimit\x12Z\n\x0b\x66ixed_limit\x18\x01 \x01(\x0b\x32\x43.envoy.extensions.filters.common.fault.v3.FaultRateLimit.FixedLimitH\x00\x12\\\n\x0cheader_limit\x18\x03 \x01(\x0b\x32\x44.envoy.extensions.filters.common.fault.v3.FaultRateLimit.HeaderLimitH\x00\x12\x34\n\npercentage\x18\x02 \x01(\x0b\x32 .envoy.type.v3.FractionalPercent\x1ah\n\nFixedLimit\x12\x1b\n\nlimit_kbps\x18\x01 \x01(\x04\x42\x07\xfa\x42\x04\x32\x02(\x01:=\x9a\xc5\x88\x1e\x38\n6envoy.config.filter.fault.v2.FaultRateLimit.FixedLimit\x1aM\n\x0bHeaderLimit:>\x9a\xc5\x88\x1e\x39\n7envoy.config.filter.fault.v2.FaultRateLimit.HeaderLimit:2\x9a\xc5\x88\x1e-\n+envoy.config.filter.fault.v2.FaultRateLimitB\x11\n\nlimit_type\x12\x03\xf8\x42\x01\x42\xa7\x01\n6io.envoyproxy.envoy.extensions.filters.common.fault.v3B\nFaultProtoP\x01ZWgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/common/fault/v3;faultv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.common.fault.v3.fault_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n6io.envoyproxy.envoy.extensions.filters.common.fault.v3B\nFaultProtoP\001ZWgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/common/fault/v3;faultv3\272\200\310\321\006\002\020\002'
  _globals['_FAULTDELAY_HEADERDELAY']._loaded_options = None
  _globals['_FAULTDELAY_HEADERDELAY']._serialized_options = b'\232\305\210\0365\n3envoy.config.filter.fault.v2.FaultDelay.HeaderDelay'
  _globals['_FAULTDELAY'].oneofs_by_name['fault_delay_secifier']._loaded_options = None
  _globals['_FAULTDELAY'].oneofs_by_name['fault_delay_secifier']._serialized_options = b'\370B\001'
  _globals['_FAULTDELAY'].fields_by_name['fixed_delay']._loaded_options = None
  _globals['_FAULTDELAY'].fields_by_name['fixed_delay']._serialized_options = b'\372B\005\252\001\002*\000'
  _globals['_FAULTDELAY']._loaded_options = None
  _globals['_FAULTDELAY']._serialized_options = b'\232\305\210\036)\n\'envoy.config.filter.fault.v2.FaultDelay'
  _globals['_FAULTRATELIMIT_FIXEDLIMIT'].fields_by_name['limit_kbps']._loaded_options = None
  _globals['_FAULTRATELIMIT_FIXEDLIMIT'].fields_by_name['limit_kbps']._serialized_options = b'\372B\0042\002(\001'
  _globals['_FAULTRATELIMIT_FIXEDLIMIT']._loaded_options = None
  _globals['_FAULTRATELIMIT_FIXEDLIMIT']._serialized_options = b'\232\305\210\0368\n6envoy.config.filter.fault.v2.FaultRateLimit.FixedLimit'
  _globals['_FAULTRATELIMIT_HEADERLIMIT']._loaded_options = None
  _globals['_FAULTRATELIMIT_HEADERLIMIT']._serialized_options = b'\232\305\210\0369\n7envoy.config.filter.fault.v2.FaultRateLimit.HeaderLimit'
  _globals['_FAULTRATELIMIT'].oneofs_by_name['limit_type']._loaded_options = None
  _globals['_FAULTRATELIMIT'].oneofs_by_name['limit_type']._serialized_options = b'\370B\001'
  _globals['_FAULTRATELIMIT']._loaded_options = None
  _globals['_FAULTRATELIMIT']._serialized_options = b'\232\305\210\036-\n+envoy.config.filter.fault.v2.FaultRateLimit'
  _globals['_FAULTDELAY']._serialized_start=251
  _globals['_FAULTDELAY']._serialized_end=666
  _globals['_FAULTDELAY_HEADERDELAY']._serialized_start=469
  _globals['_FAULTDELAY_HEADERDELAY']._serialized_end=542
  _globals['_FAULTDELAY_FAULTDELAYTYPE']._serialized_start=544
  _globals['_FAULTDELAY_FAULTDELAYTYPE']._serialized_end=571
  _globals['_FAULTRATELIMIT']._serialized_start=669
  _globals['_FAULTRATELIMIT']._serialized_end=1181
  _globals['_FAULTRATELIMIT_FIXEDLIMIT']._serialized_start=927
  _globals['_FAULTRATELIMIT_FIXEDLIMIT']._serialized_end=1031
  _globals['_FAULTRATELIMIT_HEADERLIMIT']._serialized_start=1033
  _globals['_FAULTRATELIMIT_HEADERLIMIT']._serialized_end=1110
# @@protoc_insertion_point(module_scope)
