# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/extensions/filters/http/aws_lambda/v3/aws_lambda.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/extensions/filters/http/aws_lambda/v3/aws_lambda.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<envoy/extensions/filters/http/aws_lambda/v3/aws_lambda.proto\x12+envoy.extensions.filters.http.aws_lambda.v3\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x94\x03\n\x06\x43onfig\x12\x14\n\x03\x61rn\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x1b\n\x13payload_passthrough\x18\x02 \x01(\x08\x12\x65\n\x0finvocation_mode\x18\x03 \x01(\x0e\x32\x42.envoy.extensions.filters.http.aws_lambda.v3.Config.InvocationModeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x14\n\x0chost_rewrite\x18\x04 \x01(\t\x12\x1b\n\x13\x63redentials_profile\x18\x05 \x01(\t\x12M\n\x0b\x63redentials\x18\x06 \x01(\x0b\x32\x38.envoy.extensions.filters.http.aws_lambda.v3.Credentials\"3\n\x0eInvocationMode\x12\x0f\n\x0bSYNCHRONOUS\x10\x00\x12\x10\n\x0c\x41SYNCHRONOUS\x10\x01:9\x9a\xc5\x88\x1e\x34\n2envoy.config.filter.http.aws_lambda.v2alpha.Config\"h\n\x0b\x43redentials\x12\x1e\n\raccess_key_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\"\n\x11secret_access_key\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x15\n\rsession_token\x18\x03 \x01(\t\"\x9f\x01\n\x0ePerRouteConfig\x12J\n\rinvoke_config\x18\x01 \x01(\x0b\x32\x33.envoy.extensions.filters.http.aws_lambda.v3.Config:A\x9a\xc5\x88\x1e<\n:envoy.config.filter.http.aws_lambda.v2alpha.PerRouteConfigB\xb6\x01\n9io.envoyproxy.envoy.extensions.filters.http.aws_lambda.v3B\x0e\x41wsLambdaProtoP\x01Z_github.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/aws_lambda/v3;aws_lambdav3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.aws_lambda.v3.aws_lambda_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n9io.envoyproxy.envoy.extensions.filters.http.aws_lambda.v3B\016AwsLambdaProtoP\001Z_github.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/aws_lambda/v3;aws_lambdav3\272\200\310\321\006\002\020\002'
  _globals['_CONFIG'].fields_by_name['arn']._loaded_options = None
  _globals['_CONFIG'].fields_by_name['arn']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_CONFIG'].fields_by_name['invocation_mode']._loaded_options = None
  _globals['_CONFIG'].fields_by_name['invocation_mode']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_CONFIG']._loaded_options = None
  _globals['_CONFIG']._serialized_options = b'\232\305\210\0364\n2envoy.config.filter.http.aws_lambda.v2alpha.Config'
  _globals['_CREDENTIALS'].fields_by_name['access_key_id']._loaded_options = None
  _globals['_CREDENTIALS'].fields_by_name['access_key_id']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_CREDENTIALS'].fields_by_name['secret_access_key']._loaded_options = None
  _globals['_CREDENTIALS'].fields_by_name['secret_access_key']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_PERROUTECONFIG']._loaded_options = None
  _globals['_PERROUTECONFIG']._serialized_options = b'\232\305\210\036<\n:envoy.config.filter.http.aws_lambda.v2alpha.PerRouteConfig'
  _globals['_CONFIG']._serialized_start=201
  _globals['_CONFIG']._serialized_end=605
  _globals['_CONFIG_INVOCATIONMODE']._serialized_start=495
  _globals['_CONFIG_INVOCATIONMODE']._serialized_end=546
  _globals['_CREDENTIALS']._serialized_start=607
  _globals['_CREDENTIALS']._serialized_end=711
  _globals['_PERROUTECONFIG']._serialized_start=714
  _globals['_PERROUTECONFIG']._serialized_end=873
# @@protoc_insertion_point(module_scope)
