# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/extensions/filters/http/bandwidth_limit/v3/bandwidth_limit.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/extensions/filters/http/bandwidth_limit/v3/bandwidth_limit.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFenvoy/extensions/filters/http/bandwidth_limit/v3/bandwidth_limit.proto\x12\x30\x65nvoy.extensions.filters.http.bandwidth_limit.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xfe\x03\n\x0e\x42\x61ndwidthLimit\x12\x1c\n\x0bstat_prefix\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12j\n\x0b\x65nable_mode\x18\x02 \x01(\x0e\x32K.envoy.extensions.filters.http.bandwidth_limit.v3.BandwidthLimit.EnableModeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x39\n\nlimit_kbps\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt64ValueB\x07\xfa\x42\x04\x32\x02(\x01\x12\x43\n\rfill_interval\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationB\x11\xfa\x42\x0e\xaa\x01\x0b\"\x02\x08\x01\x32\x05\x10\x80\xda\xc4\t\x12\x41\n\x0fruntime_enabled\x18\x05 \x01(\x0b\x32(.envoy.config.core.v3.RuntimeFeatureFlag\x12 \n\x18\x65nable_response_trailers\x18\x06 \x01(\x08\x12,\n\x17response_trailer_prefix\x18\x07 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x01\xc8\x01\x00\"O\n\nEnableMode\x12\x0c\n\x08\x44ISABLED\x10\x00\x12\x0b\n\x07REQUEST\x10\x01\x12\x0c\n\x08RESPONSE\x10\x02\x12\x18\n\x14REQUEST_AND_RESPONSE\x10\x03\x42\xca\x01\n>io.envoyproxy.envoy.extensions.filters.http.bandwidth_limit.v3B\x13\x42\x61ndwidthLimitProtoP\x01Zigithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/bandwidth_limit/v3;bandwidth_limitv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.bandwidth_limit.v3.bandwidth_limit_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n>io.envoyproxy.envoy.extensions.filters.http.bandwidth_limit.v3B\023BandwidthLimitProtoP\001Zigithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/bandwidth_limit/v3;bandwidth_limitv3\272\200\310\321\006\002\020\002'
  _globals['_BANDWIDTHLIMIT'].fields_by_name['stat_prefix']._loaded_options = None
  _globals['_BANDWIDTHLIMIT'].fields_by_name['stat_prefix']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_BANDWIDTHLIMIT'].fields_by_name['enable_mode']._loaded_options = None
  _globals['_BANDWIDTHLIMIT'].fields_by_name['enable_mode']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_BANDWIDTHLIMIT'].fields_by_name['limit_kbps']._loaded_options = None
  _globals['_BANDWIDTHLIMIT'].fields_by_name['limit_kbps']._serialized_options = b'\372B\0042\002(\001'
  _globals['_BANDWIDTHLIMIT'].fields_by_name['fill_interval']._loaded_options = None
  _globals['_BANDWIDTHLIMIT'].fields_by_name['fill_interval']._serialized_options = b'\372B\016\252\001\013\"\002\010\0012\005\020\200\332\304\t'
  _globals['_BANDWIDTHLIMIT'].fields_by_name['response_trailer_prefix']._loaded_options = None
  _globals['_BANDWIDTHLIMIT'].fields_by_name['response_trailer_prefix']._serialized_options = b'\372B\010r\006\300\001\001\310\001\000'
  _globals['_BANDWIDTHLIMIT']._serialized_start=278
  _globals['_BANDWIDTHLIMIT']._serialized_end=788
  _globals['_BANDWIDTHLIMIT_ENABLEMODE']._serialized_start=709
  _globals['_BANDWIDTHLIMIT_ENABLEMODE']._serialized_end=788
# @@protoc_insertion_point(module_scope)
