# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/extensions/access_loggers/open_telemetry/v3/logs_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/extensions/access_loggers/open_telemetry/v3/logs_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import extension_pb2 as envoy_dot_config_dot_core_dot_v3_dot_extension__pb2
from envoy.extensions.access_loggers.grpc.v3 import als_pb2 as envoy_dot_extensions_dot_access__loggers_dot_grpc_dot_v3_dot_als__pb2
from opentelemetry.proto.common.v1 import common_pb2 as opentelemetry_dot_proto_dot_common_dot_v1_dot_common__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDenvoy/extensions/access_loggers/open_telemetry/v3/logs_service.proto\x12\x31\x65nvoy.extensions.access_loggers.open_telemetry.v3\x1a$envoy/config/core/v3/extension.proto\x1a\x31\x65nvoy/extensions/access_loggers/grpc/v3/als.proto\x1a*opentelemetry/proto/common/v1/common.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xba\x03\n\x1cOpenTelemetryAccessLogConfig\x12\x63\n\rcommon_config\x18\x01 \x01(\x0b\x32\x42.envoy.extensions.access_loggers.grpc.v3.CommonGrpcAccessLogConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x1e\n\x16\x64isable_builtin_labels\x18\x05 \x01(\x08\x12H\n\x13resource_attributes\x18\x04 \x01(\x0b\x32+.opentelemetry.proto.common.v1.KeyValueList\x12\x35\n\x04\x62ody\x18\x02 \x01(\x0b\x32\'.opentelemetry.proto.common.v1.AnyValue\x12?\n\nattributes\x18\x03 \x01(\x0b\x32+.opentelemetry.proto.common.v1.KeyValueList\x12\x13\n\x0bstat_prefix\x18\x06 \x01(\t\x12>\n\nformatters\x18\x07 \x03(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfigB\xc8\x01\n?io.envoyproxy.envoy.extensions.access_loggers.open_telemetry.v3B\x10LogsServiceProtoP\x01Zigithub.com/envoyproxy/go-control-plane/envoy/extensions/access_loggers/open_telemetry/v3;open_telemetryv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.access_loggers.open_telemetry.v3.logs_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n?io.envoyproxy.envoy.extensions.access_loggers.open_telemetry.v3B\020LogsServiceProtoP\001Zigithub.com/envoyproxy/go-control-plane/envoy/extensions/access_loggers/open_telemetry/v3;open_telemetryv3\272\200\310\321\006\002\020\002'
  _globals['_OPENTELEMETRYACCESSLOGCONFIG'].fields_by_name['common_config']._loaded_options = None
  _globals['_OPENTELEMETRYACCESSLOGCONFIG'].fields_by_name['common_config']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_OPENTELEMETRYACCESSLOGCONFIG']._serialized_start=313
  _globals['_OPENTELEMETRYACCESSLOGCONFIG']._serialized_end=755
# @@protoc_insertion_point(module_scope)
