# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: google/rpc/error_details.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'google/rpc/error_details.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1egoogle/rpc/error_details.proto\x12\ngoogle.rpc\x1a\x1egoogle/protobuf/duration.proto\"\x93\x01\n\tErrorInfo\x12\x0e\n\x06reason\x18\x01 \x01(\t\x12\x0e\n\x06\x64omain\x18\x02 \x01(\t\x12\x35\n\x08metadata\x18\x03 \x03(\x0b\x32#.google.rpc.ErrorInfo.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\";\n\tRetryInfo\x12.\n\x0bretry_delay\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\"2\n\tDebugInfo\x12\x15\n\rstack_entries\x18\x01 \x03(\t\x12\x0e\n\x06\x64\x65tail\x18\x02 \x01(\t\"y\n\x0cQuotaFailure\x12\x36\n\nviolations\x18\x01 \x03(\x0b\x32\".google.rpc.QuotaFailure.Violation\x1a\x31\n\tViolation\x12\x0f\n\x07subject\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\"\x95\x01\n\x13PreconditionFailure\x12=\n\nviolations\x18\x01 \x03(\x0b\x32).google.rpc.PreconditionFailure.Violation\x1a?\n\tViolation\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0f\n\x07subject\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\"\x83\x01\n\nBadRequest\x12?\n\x10\x66ield_violations\x18\x01 \x03(\x0b\x32%.google.rpc.BadRequest.FieldViolation\x1a\x34\n\x0e\x46ieldViolation\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\"7\n\x0bRequestInfo\x12\x12\n\nrequest_id\x18\x01 \x01(\t\x12\x14\n\x0cserving_data\x18\x02 \x01(\t\"`\n\x0cResourceInfo\x12\x15\n\rresource_type\x18\x01 \x01(\t\x12\x15\n\rresource_name\x18\x02 \x01(\t\x12\r\n\x05owner\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\"V\n\x04Help\x12$\n\x05links\x18\x01 \x03(\x0b\x32\x15.google.rpc.Help.Link\x1a(\n\x04Link\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\"3\n\x10LocalizedMessage\x12\x0e\n\x06locale\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\tBl\n\x0e\x63om.google.rpcB\x11\x45rrorDetailsProtoP\x01Z?google.golang.org/genproto/googleapis/rpc/errdetails;errdetails\xa2\x02\x03RPCb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.rpc.error_details_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\016com.google.rpcB\021ErrorDetailsProtoP\001Z?google.golang.org/genproto/googleapis/rpc/errdetails;errdetails\242\002\003RPC'
  _globals['_ERRORINFO_METADATAENTRY']._loaded_options = None
  _globals['_ERRORINFO_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_ERRORINFO']._serialized_start=79
  _globals['_ERRORINFO']._serialized_end=226
  _globals['_ERRORINFO_METADATAENTRY']._serialized_start=179
  _globals['_ERRORINFO_METADATAENTRY']._serialized_end=226
  _globals['_RETRYINFO']._serialized_start=228
  _globals['_RETRYINFO']._serialized_end=287
  _globals['_DEBUGINFO']._serialized_start=289
  _globals['_DEBUGINFO']._serialized_end=339
  _globals['_QUOTAFAILURE']._serialized_start=341
  _globals['_QUOTAFAILURE']._serialized_end=462
  _globals['_QUOTAFAILURE_VIOLATION']._serialized_start=413
  _globals['_QUOTAFAILURE_VIOLATION']._serialized_end=462
  _globals['_PRECONDITIONFAILURE']._serialized_start=465
  _globals['_PRECONDITIONFAILURE']._serialized_end=614
  _globals['_PRECONDITIONFAILURE_VIOLATION']._serialized_start=551
  _globals['_PRECONDITIONFAILURE_VIOLATION']._serialized_end=614
  _globals['_BADREQUEST']._serialized_start=617
  _globals['_BADREQUEST']._serialized_end=748
  _globals['_BADREQUEST_FIELDVIOLATION']._serialized_start=696
  _globals['_BADREQUEST_FIELDVIOLATION']._serialized_end=748
  _globals['_REQUESTINFO']._serialized_start=750
  _globals['_REQUESTINFO']._serialized_end=805
  _globals['_RESOURCEINFO']._serialized_start=807
  _globals['_RESOURCEINFO']._serialized_end=903
  _globals['_HELP']._serialized_start=905
  _globals['_HELP']._serialized_end=991
  _globals['_HELP_LINK']._serialized_start=951
  _globals['_HELP_LINK']._serialized_end=991
  _globals['_LOCALIZEDMESSAGE']._serialized_start=993
  _globals['_LOCALIZEDMESSAGE']._serialized_end=1044
# @@protoc_insertion_point(module_scope)
