# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/api/v2/auth/secret.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/api/v2/auth/secret.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.auth import common_pb2 as envoy_dot_api_dot_v2_dot_auth_dot_common__pb2
from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.api.v2.core import config_source_pb2 as envoy_dot_api_dot_v2_dot_core_dot_config__source__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import sensitive_pb2 as udpa_dot_annotations_dot_sensitive__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x65nvoy/api/v2/auth/secret.proto\x12\x11\x65nvoy.api.v2.auth\x1a\x1e\x65nvoy/api/v2/auth/common.proto\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a%envoy/api/v2/core/config_source.proto\x1a\x1eudpa/annotations/migrate.proto\x1a udpa/annotations/sensitive.proto\x1a\x1dudpa/annotations/status.proto\"F\n\rGenericSecret\x12\x35\n\x06secret\x18\x01 \x01(\x0b\x32\x1d.envoy.api.v2.core.DataSourceB\x06\xb8\xb7\x8b\xa4\x02\x01\"T\n\x0fSdsSecretConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x33\n\nsds_config\x18\x02 \x01(\x0b\x32\x1f.envoy.api.v2.core.ConfigSource\"\xaf\x02\n\x06Secret\x12\x0c\n\x04name\x18\x01 \x01(\t\x12<\n\x0ftls_certificate\x18\x02 \x01(\x0b\x32!.envoy.api.v2.auth.TlsCertificateH\x00\x12\x46\n\x13session_ticket_keys\x18\x03 \x01(\x0b\x32\'.envoy.api.v2.auth.TlsSessionTicketKeysH\x00\x12M\n\x12validation_context\x18\x04 \x01(\x0b\x32/.envoy.api.v2.auth.CertificateValidationContextH\x00\x12:\n\x0egeneric_secret\x18\x05 \x01(\x0b\x32 .envoy.api.v2.auth.GenericSecretH\x00\x42\x06\n\x04typeB\xa3\x01\n\x1fio.envoyproxy.envoy.api.v2.authB\x0bSecretProtoP\x01Z8github.com/envoyproxy/go-control-plane/envoy/api/v2/auth\xf2\x98\xfe\x8f\x05+\x12)envoy.extensions.transport_sockets.tls.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.api.v2.auth.secret_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037io.envoyproxy.envoy.api.v2.authB\013SecretProtoP\001Z8github.com/envoyproxy/go-control-plane/envoy/api/v2/auth\362\230\376\217\005+\022)envoy.extensions.transport_sockets.tls.v3\272\200\310\321\006\002\020\001'
  _globals['_GENERICSECRET'].fields_by_name['secret']._loaded_options = None
  _globals['_GENERICSECRET'].fields_by_name['secret']._serialized_options = b'\270\267\213\244\002\001'
  _globals['_GENERICSECRET']._serialized_start=251
  _globals['_GENERICSECRET']._serialized_end=321
  _globals['_SDSSECRETCONFIG']._serialized_start=323
  _globals['_SDSSECRETCONFIG']._serialized_end=407
  _globals['_SECRET']._serialized_start=410
  _globals['_SECRET']._serialized_end=713
# @@protoc_insertion_point(module_scope)
