# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/api/v2/listener.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/api/v2/listener.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import address_pb2 as envoy_dot_api_dot_v2_dot_core_dot_address__pb2
from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.api.v2.core import socket_option_pb2 as envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
from envoy.api.v2.listener import listener_components_pb2 as envoy_dot_api_dot_v2_dot_listener_dot_listener__components__pb2
from envoy.api.v2.listener import udp_listener_config_pb2 as envoy_dot_api_dot_v2_dot_listener_dot_udp__listener__config__pb2
from envoy.config.filter.accesslog.v2 import accesslog_pb2 as envoy_dot_config_dot_filter_dot_accesslog_dot_v2_dot_accesslog__pb2
from envoy.config.listener.v2 import api_listener_pb2 as envoy_dot_config_dot_listener_dot_v2_dot_api__listener__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x65nvoy/api/v2/listener.proto\x12\x0c\x65nvoy.api.v2\x1a\x1f\x65nvoy/api/v2/core/address.proto\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a%envoy/api/v2/core/socket_option.proto\x1a/envoy/api/v2/listener/listener_components.proto\x1a/envoy/api/v2/listener/udp_listener_config.proto\x1a\x30\x65nvoy/config/filter/accesslog/v2/accesslog.proto\x1a+envoy/config/listener/v2/api_listener.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xaa\x0b\n\x08Listener\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x35\n\x07\x61\x64\x64ress\x18\x02 \x01(\x0b\x32\x1a.envoy.api.v2.core.AddressB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x39\n\rfilter_chains\x18\x03 \x03(\x0b\x32\".envoy.api.v2.listener.FilterChain\x12\x38\n\x10use_original_dst\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\x02\x18\x01\x12G\n!per_connection_buffer_limit_bytes\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12-\n\x08metadata\x18\x06 \x01(\x0b\x32\x1b.envoy.api.v2.core.Metadata\x12:\n\rdeprecated_v1\x18\x07 \x01(\x0b\x32#.envoy.api.v2.Listener.DeprecatedV1\x12\x34\n\ndrain_type\x18\x08 \x01(\x0e\x32 .envoy.api.v2.Listener.DrainType\x12?\n\x10listener_filters\x18\t \x03(\x0b\x32%.envoy.api.v2.listener.ListenerFilter\x12;\n\x18listener_filters_timeout\x18\x0f \x01(\x0b\x32\x19.google.protobuf.Duration\x12,\n$continue_on_listener_filters_timeout\x18\x11 \x01(\x08\x12/\n\x0btransparent\x18\n \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12,\n\x08\x66reebind\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x37\n\x0esocket_options\x18\r \x03(\x0b\x32\x1f.envoy.api.v2.core.SocketOption\x12@\n\x1atcp_fast_open_queue_length\x18\x0c \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12>\n\x11traffic_direction\x18\x10 \x01(\x0e\x32#.envoy.api.v2.core.TrafficDirection\x12\x45\n\x13udp_listener_config\x18\x12 \x01(\x0b\x32(.envoy.api.v2.listener.UdpListenerConfig\x12;\n\x0c\x61pi_listener\x18\x13 \x01(\x0b\x32%.envoy.config.listener.v2.ApiListener\x12Q\n\x19\x63onnection_balance_config\x18\x14 \x01(\x0b\x32..envoy.api.v2.Listener.ConnectionBalanceConfig\x12\x12\n\nreuse_port\x18\x15 \x01(\x08\x12?\n\naccess_log\x18\x16 \x03(\x0b\x32+.envoy.config.filter.accesslog.v2.AccessLog\x1a@\n\x0c\x44\x65precatedV1\x12\x30\n\x0c\x62ind_to_port\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x1a\x94\x01\n\x17\x43onnectionBalanceConfig\x12T\n\rexact_balance\x18\x01 \x01(\x0b\x32;.envoy.api.v2.Listener.ConnectionBalanceConfig.ExactBalanceH\x00\x1a\x0e\n\x0c\x45xactBalanceB\x13\n\x0c\x62\x61lance_type\x12\x03\xf8\x42\x01\")\n\tDrainType\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x0f\n\x0bMODIFY_ONLY\x10\x01J\x04\x08\x0e\x10\x0f\x42\x90\x01\n\x1aio.envoyproxy.envoy.api.v2B\rListenerProtoP\x01Z9github.com/envoyproxy/go-control-plane/envoy/api/v2;apiv2\xf2\x98\xfe\x8f\x05\x1a\x12\x18\x65nvoy.config.listener.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.api.v2.listener_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032io.envoyproxy.envoy.api.v2B\rListenerProtoP\001Z9github.com/envoyproxy/go-control-plane/envoy/api/v2;apiv2\362\230\376\217\005\032\022\030envoy.config.listener.v3\272\200\310\321\006\002\020\001'
  _globals['_LISTENER_CONNECTIONBALANCECONFIG'].oneofs_by_name['balance_type']._loaded_options = None
  _globals['_LISTENER_CONNECTIONBALANCECONFIG'].oneofs_by_name['balance_type']._serialized_options = b'\370B\001'
  _globals['_LISTENER'].fields_by_name['address']._loaded_options = None
  _globals['_LISTENER'].fields_by_name['address']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_LISTENER'].fields_by_name['use_original_dst']._loaded_options = None
  _globals['_LISTENER'].fields_by_name['use_original_dst']._serialized_options = b'\030\001'
  _globals['_LISTENER']._serialized_start=493
  _globals['_LISTENER']._serialized_end=1943
  _globals['_LISTENER_DEPRECATEDV1']._serialized_start=1679
  _globals['_LISTENER_DEPRECATEDV1']._serialized_end=1743
  _globals['_LISTENER_CONNECTIONBALANCECONFIG']._serialized_start=1746
  _globals['_LISTENER_CONNECTIONBALANCECONFIG']._serialized_end=1894
  _globals['_LISTENER_CONNECTIONBALANCECONFIG_EXACTBALANCE']._serialized_start=1859
  _globals['_LISTENER_CONNECTIONBALANCECONFIG_EXACTBALANCE']._serialized_end=1873
  _globals['_LISTENER_DRAINTYPE']._serialized_start=1896
  _globals['_LISTENER_DRAINTYPE']._serialized_end=1937
# @@protoc_insertion_point(module_scope)
