# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/config/bootstrap/v2/bootstrap.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/config/bootstrap/v2/bootstrap.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.auth import secret_pb2 as envoy_dot_api_dot_v2_dot_auth_dot_secret__pb2
from envoy.api.v2 import cluster_pb2 as envoy_dot_api_dot_v2_dot_cluster__pb2
from envoy.api.v2.core import address_pb2 as envoy_dot_api_dot_v2_dot_core_dot_address__pb2
from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.api.v2.core import config_source_pb2 as envoy_dot_api_dot_v2_dot_core_dot_config__source__pb2
from envoy.api.v2.core import event_service_config_pb2 as envoy_dot_api_dot_v2_dot_core_dot_event__service__config__pb2
from envoy.api.v2.core import socket_option_pb2 as envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
from envoy.api.v2 import listener_pb2 as envoy_dot_api_dot_v2_dot_listener__pb2
from envoy.config.metrics.v2 import stats_pb2 as envoy_dot_config_dot_metrics_dot_v2_dot_stats__pb2
from envoy.config.overload.v2alpha import overload_pb2 as envoy_dot_config_dot_overload_dot_v2alpha_dot_overload__pb2
from envoy.config.trace.v2 import http_tracer_pb2 as envoy_dot_config_dot_trace_dot_v2_dot_http__tracer__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)envoy/config/bootstrap/v2/bootstrap.proto\x12\x19\x65nvoy.config.bootstrap.v2\x1a\x1e\x65nvoy/api/v2/auth/secret.proto\x1a\x1a\x65nvoy/api/v2/cluster.proto\x1a\x1f\x65nvoy/api/v2/core/address.proto\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a%envoy/api/v2/core/config_source.proto\x1a,envoy/api/v2/core/event_service_config.proto\x1a%envoy/api/v2/core/socket_option.proto\x1a\x1b\x65nvoy/api/v2/listener.proto\x1a#envoy/config/metrics/v2/stats.proto\x1a,envoy/config/overload/v2alpha/overload.proto\x1a\'envoy/config/trace/v2/http_tracer.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x80\x0b\n\tBootstrap\x12%\n\x04node\x18\x01 \x01(\x0b\x32\x17.envoy.api.v2.core.Node\x12N\n\x10static_resources\x18\x02 \x01(\x0b\x32\x34.envoy.config.bootstrap.v2.Bootstrap.StaticResources\x12P\n\x11\x64ynamic_resources\x18\x03 \x01(\x0b\x32\x35.envoy.config.bootstrap.v2.Bootstrap.DynamicResources\x12\x42\n\x0f\x63luster_manager\x18\x04 \x01(\x0b\x32).envoy.config.bootstrap.v2.ClusterManager\x12\x36\n\nhds_config\x18\x0e \x01(\x0b\x32\".envoy.api.v2.core.ApiConfigSource\x12\x12\n\nflags_path\x18\x05 \x01(\t\x12\x37\n\x0bstats_sinks\x18\x06 \x03(\x0b\x32\".envoy.config.metrics.v2.StatsSink\x12:\n\x0cstats_config\x18\r \x01(\x0b\x32$.envoy.config.metrics.v2.StatsConfig\x12J\n\x14stats_flush_interval\x18\x07 \x01(\x0b\x32\x19.google.protobuf.DurationB\x11\xfa\x42\x0e\xaa\x01\x0b\x1a\x03\x08\xac\x02\x32\x04\x10\xc0\x84=\x12\x35\n\x08watchdog\x18\x08 \x01(\x0b\x32#.envoy.config.bootstrap.v2.Watchdog\x12/\n\x07tracing\x18\t \x01(\x0b\x32\x1e.envoy.config.trace.v2.Tracing\x12=\n\x07runtime\x18\x0b \x01(\x0b\x32\".envoy.config.bootstrap.v2.RuntimeB\x08\x18\x01\xb8\xee\xf2\xd2\x05\x01\x12\x42\n\x0flayered_runtime\x18\x11 \x01(\x0b\x32).envoy.config.bootstrap.v2.LayeredRuntime\x12/\n\x05\x61\x64min\x18\x0c \x01(\x0b\x32 .envoy.config.bootstrap.v2.Admin\x12H\n\x10overload_manager\x18\x0f \x01(\x0b\x32..envoy.config.overload.v2alpha.OverloadManager\x12\x1f\n\x17\x65nable_dispatcher_stats\x18\x10 \x01(\x08\x12\x15\n\rheader_prefix\x18\x12 \x01(\t\x12\x43\n\x1dstats_server_version_override\x18\x13 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12\x1f\n\x17use_tcp_for_dns_lookups\x18\x14 \x01(\x08\x1a\x91\x01\n\x0fStaticResources\x12)\n\tlisteners\x18\x01 \x03(\x0b\x32\x16.envoy.api.v2.Listener\x12\'\n\x08\x63lusters\x18\x02 \x03(\x0b\x32\x15.envoy.api.v2.Cluster\x12*\n\x07secrets\x18\x03 \x03(\x0b\x32\x19.envoy.api.v2.auth.Secret\x1a\xba\x01\n\x10\x44ynamicResources\x12\x33\n\nlds_config\x18\x01 \x01(\x0b\x32\x1f.envoy.api.v2.core.ConfigSource\x12\x33\n\ncds_config\x18\x02 \x01(\x0b\x32\x1f.envoy.api.v2.core.ConfigSource\x12\x36\n\nads_config\x18\x03 \x01(\x0b\x32\".envoy.api.v2.core.ApiConfigSourceJ\x04\x08\x04\x10\x05J\x04\x08\n\x10\x0b\"\x9c\x01\n\x05\x41\x64min\x12\x17\n\x0f\x61\x63\x63\x65ss_log_path\x18\x01 \x01(\t\x12\x14\n\x0cprofile_path\x18\x02 \x01(\t\x12+\n\x07\x61\x64\x64ress\x18\x03 \x01(\x0b\x32\x1a.envoy.api.v2.core.Address\x12\x37\n\x0esocket_options\x18\x04 \x03(\x0b\x32\x1f.envoy.api.v2.core.SocketOption\"\xe9\x02\n\x0e\x43lusterManager\x12\x1a\n\x12local_cluster_name\x18\x01 \x01(\t\x12U\n\x11outlier_detection\x18\x02 \x01(\x0b\x32:.envoy.config.bootstrap.v2.ClusterManager.OutlierDetection\x12;\n\x14upstream_bind_config\x18\x03 \x01(\x0b\x32\x1d.envoy.api.v2.core.BindConfig\x12=\n\x11load_stats_config\x18\x04 \x01(\x0b\x32\".envoy.api.v2.core.ApiConfigSource\x1ah\n\x10OutlierDetection\x12\x16\n\x0e\x65vent_log_path\x18\x01 \x01(\t\x12<\n\revent_service\x18\x02 \x01(\x0b\x32%.envoy.api.v2.core.EventServiceConfig\"\xd7\x01\n\x08Watchdog\x12/\n\x0cmiss_timeout\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x33\n\x10megamiss_timeout\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12/\n\x0ckill_timeout\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x34\n\x11multikill_timeout\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\"{\n\x07Runtime\x12\x14\n\x0csymlink_root\x18\x01 \x01(\t\x12\x14\n\x0csubdirectory\x18\x02 \x01(\t\x12\x1d\n\x15override_subdirectory\x18\x03 \x01(\t\x12%\n\x04\x62\x61se\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\"\x83\x04\n\x0cRuntimeLayer\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12/\n\x0cstatic_layer\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructH\x00\x12G\n\ndisk_layer\x18\x03 \x01(\x0b\x32\x31.envoy.config.bootstrap.v2.RuntimeLayer.DiskLayerH\x00\x12I\n\x0b\x61\x64min_layer\x18\x04 \x01(\x0b\x32\x32.envoy.config.bootstrap.v2.RuntimeLayer.AdminLayerH\x00\x12G\n\nrtds_layer\x18\x05 \x01(\x0b\x32\x31.envoy.config.bootstrap.v2.RuntimeLayer.RtdsLayerH\x00\x1aW\n\tDiskLayer\x12\x14\n\x0csymlink_root\x18\x01 \x01(\t\x12\x14\n\x0csubdirectory\x18\x03 \x01(\t\x12\x1e\n\x16\x61ppend_service_cluster\x18\x02 \x01(\x08\x1a\x0c\n\nAdminLayer\x1aO\n\tRtdsLayer\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x34\n\x0brtds_config\x18\x02 \x01(\x0b\x32\x1f.envoy.api.v2.core.ConfigSourceB\x16\n\x0flayer_specifier\x12\x03\xf8\x42\x01\"I\n\x0eLayeredRuntime\x12\x37\n\x06layers\x18\x01 \x03(\x0b\x32\'.envoy.config.bootstrap.v2.RuntimeLayerB\x91\x01\n\'io.envoyproxy.envoy.config.bootstrap.v2B\x0e\x42ootstrapProtoP\x01ZLgithub.com/envoyproxy/go-control-plane/envoy/config/bootstrap/v2;bootstrapv2\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.bootstrap.v2.bootstrap_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\'io.envoyproxy.envoy.config.bootstrap.v2B\016BootstrapProtoP\001ZLgithub.com/envoyproxy/go-control-plane/envoy/config/bootstrap/v2;bootstrapv2\272\200\310\321\006\002\020\001'
  _globals['_BOOTSTRAP'].fields_by_name['stats_flush_interval']._loaded_options = None
  _globals['_BOOTSTRAP'].fields_by_name['stats_flush_interval']._serialized_options = b'\372B\016\252\001\013\032\003\010\254\0022\004\020\300\204='
  _globals['_BOOTSTRAP'].fields_by_name['runtime']._loaded_options = None
  _globals['_BOOTSTRAP'].fields_by_name['runtime']._serialized_options = b'\030\001\270\356\362\322\005\001'
  _globals['_RUNTIMELAYER'].oneofs_by_name['layer_specifier']._loaded_options = None
  _globals['_RUNTIMELAYER'].oneofs_by_name['layer_specifier']._serialized_options = b'\370B\001'
  _globals['_RUNTIMELAYER'].fields_by_name['name']._loaded_options = None
  _globals['_RUNTIMELAYER'].fields_by_name['name']._serialized_options = b'\372B\004r\002 \001'
  _globals['_BOOTSTRAP']._serialized_start=660
  _globals['_BOOTSTRAP']._serialized_end=2068
  _globals['_BOOTSTRAP_STATICRESOURCES']._serialized_start=1728
  _globals['_BOOTSTRAP_STATICRESOURCES']._serialized_end=1873
  _globals['_BOOTSTRAP_DYNAMICRESOURCES']._serialized_start=1876
  _globals['_BOOTSTRAP_DYNAMICRESOURCES']._serialized_end=2062
  _globals['_ADMIN']._serialized_start=2071
  _globals['_ADMIN']._serialized_end=2227
  _globals['_CLUSTERMANAGER']._serialized_start=2230
  _globals['_CLUSTERMANAGER']._serialized_end=2591
  _globals['_CLUSTERMANAGER_OUTLIERDETECTION']._serialized_start=2487
  _globals['_CLUSTERMANAGER_OUTLIERDETECTION']._serialized_end=2591
  _globals['_WATCHDOG']._serialized_start=2594
  _globals['_WATCHDOG']._serialized_end=2809
  _globals['_RUNTIME']._serialized_start=2811
  _globals['_RUNTIME']._serialized_end=2934
  _globals['_RUNTIMELAYER']._serialized_start=2937
  _globals['_RUNTIMELAYER']._serialized_end=3452
  _globals['_RUNTIMELAYER_DISKLAYER']._serialized_start=3246
  _globals['_RUNTIMELAYER_DISKLAYER']._serialized_end=3333
  _globals['_RUNTIMELAYER_ADMINLAYER']._serialized_start=3335
  _globals['_RUNTIMELAYER_ADMINLAYER']._serialized_end=3347
  _globals['_RUNTIMELAYER_RTDSLAYER']._serialized_start=3349
  _globals['_RUNTIMELAYER_RTDSLAYER']._serialized_end=3428
  _globals['_LAYEREDRUNTIME']._serialized_start=3454
  _globals['_LAYEREDRUNTIME']._serialized_end=3527
# @@protoc_insertion_point(module_scope)
