# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/extensions/filters/http/gzip/v3/gzip.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/extensions/filters/http/gzip/v3/gzip.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.extensions.filters.http.compressor.v3 import compressor_pb2 as envoy_dot_extensions_dot_filters_dot_http_dot_compressor_dot_v3_dot_compressor__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0envoy/extensions/filters/http/gzip/v3/gzip.proto\x12%envoy.extensions.filters.http.gzip.v3\x1a<envoy/extensions/filters/http/compressor/v3/compressor.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xc1\x06\n\x04Gzip\x12=\n\x0cmemory_level\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\t\xfa\x42\x06*\x04\x18\t(\x01\x12\x66\n\x11\x63ompression_level\x18\x03 \x01(\x0e\x32\x41.envoy.extensions.filters.http.gzip.v3.Gzip.CompressionLevel.EnumB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12g\n\x14\x63ompression_strategy\x18\x04 \x01(\x0e\x32?.envoy.extensions.filters.http.gzip.v3.Gzip.CompressionStrategyB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12<\n\x0bwindow_bits\x18\t \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\t\xfa\x42\x06*\x04\x18\x0f(\t\x12K\n\ncompressor\x18\n \x01(\x0b\x32\x37.envoy.extensions.filters.http.compressor.v3.Compressor\x12>\n\nchunk_size\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x0c\xfa\x42\t*\x07\x18\x80\x80\x04(\x80 \x1a{\n\x10\x43ompressionLevel\"(\n\x04\x45num\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x08\n\x04\x42\x45ST\x10\x01\x12\t\n\x05SPEED\x10\x02:=\x9a\xc5\x88\x1e\x38\n6envoy.config.filter.http.gzip.v2.Gzip.CompressionLevel\"F\n\x13\x43ompressionStrategy\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x0c\n\x08\x46ILTERED\x10\x01\x12\x0b\n\x07HUFFMAN\x10\x02\x12\x07\n\x03RLE\x10\x03:,\x9a\xc5\x88\x1e\'\n%envoy.config.filter.http.gzip.v2.GzipJ\x04\x08\x02\x10\x03J\x04\x08\x06\x10\x07J\x04\x08\x07\x10\x08J\x04\x08\x08\x10\tR\x0e\x63ontent_lengthR\x0c\x63ontent_typeR\x16\x64isable_on_etag_headerR\x1dremove_accept_encoding_headerB\x9f\x01\n3io.envoyproxy.envoy.extensions.filters.http.gzip.v3B\tGzipProtoP\x01ZSgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/gzip/v3;gzipv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.gzip.v3.gzip_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n3io.envoyproxy.envoy.extensions.filters.http.gzip.v3B\tGzipProtoP\001ZSgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/gzip/v3;gzipv3\272\200\310\321\006\002\020\002'
  _globals['_GZIP_COMPRESSIONLEVEL']._loaded_options = None
  _globals['_GZIP_COMPRESSIONLEVEL']._serialized_options = b'\232\305\210\0368\n6envoy.config.filter.http.gzip.v2.Gzip.CompressionLevel'
  _globals['_GZIP'].fields_by_name['memory_level']._loaded_options = None
  _globals['_GZIP'].fields_by_name['memory_level']._serialized_options = b'\372B\006*\004\030\t(\001'
  _globals['_GZIP'].fields_by_name['compression_level']._loaded_options = None
  _globals['_GZIP'].fields_by_name['compression_level']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_GZIP'].fields_by_name['compression_strategy']._loaded_options = None
  _globals['_GZIP'].fields_by_name['compression_strategy']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_GZIP'].fields_by_name['window_bits']._loaded_options = None
  _globals['_GZIP'].fields_by_name['window_bits']._serialized_options = b'\372B\006*\004\030\017(\t'
  _globals['_GZIP'].fields_by_name['chunk_size']._loaded_options = None
  _globals['_GZIP'].fields_by_name['chunk_size']._serialized_options = b'\372B\t*\007\030\200\200\004(\200 '
  _globals['_GZIP']._loaded_options = None
  _globals['_GZIP']._serialized_options = b'\232\305\210\036\'\n%envoy.config.filter.http.gzip.v2.Gzip'
  _globals['_GZIP']._serialized_start=277
  _globals['_GZIP']._serialized_end=1110
  _globals['_GZIP_COMPRESSIONLEVEL']._serialized_start=760
  _globals['_GZIP_COMPRESSIONLEVEL']._serialized_end=883
  _globals['_GZIP_COMPRESSIONLEVEL_ENUM']._serialized_start=780
  _globals['_GZIP_COMPRESSIONLEVEL_ENUM']._serialized_end=820
  _globals['_GZIP_COMPRESSIONSTRATEGY']._serialized_start=885
  _globals['_GZIP_COMPRESSIONSTRATEGY']._serialized_end=955
# @@protoc_insertion_point(module_scope)
